@@ -855,35 +855,48 @@ class Font(object):
 
         :raises ValueError: if the computed PostScript-name is longer than 63 characters.
         """
+        family_name = family_name or ""
         family_name = (
             family_name.strip()
             or self.get_name(self.NAME_TYPOGRAPHIC_FAMILY_NAME)
+            or self.get_name(self.NAME_WWS_FAMILY_NAME)
             or self.get_name(self.NAME_FAMILY_NAME)
         )
+        style_name = style_name or ""
         style_name = (
             style_name.strip()
             or self.get_name(self.NAME_TYPOGRAPHIC_SUBFAMILY_NAME)
+            or self.get_name(self.NAME_WWS_SUBFAMILY_NAME)
             or self.get_name(self.NAME_SUBFAMILY_NAME)
         )
+        concat_names = lambda a, b: f"{a} {b}" if not a.endswith(f" {b}") else a
+
+        # typographic and wws names
         typographic_family_name = family_name
         typographic_subfamily_name = style_name
         wws_family_name = family_name
         wws_subfamily_name = style_name
 
+        # family name, subfamily name and full name
         family_name_parts = [family_name]
         style_name_parts = style_name.split(" ")
         subfamily_name_parts = style_name_parts.copy()
+        subfamily_names = ["regular", "italic", "bold", "bold italic"]
+        subfamily_name_default = subfamily_names[0]
         for name_part in style_name_parts:
-            if name_part.lower() not in ["regular", "italic", "bold"]:
+            if name_part.lower() not in subfamily_names:
                 family_name_parts.append(name_part)
                 subfamily_name_parts.remove(name_part)
-        subfamily_name_parts = subfamily_name_parts or ["Regular"]
+        subfamily_name_parts = subfamily_name_parts or [subfamily_name_default]
         family_name = " ".join(family_name_parts)
-        subfamily_name = " ".join(subfamily_name_parts)
-        concat_names = lambda a, b: f"{a} {b}" if not a.endswith(b) else a
+        subfamily_name = " ".join(subfamily_name_parts).lower()
+        if subfamily_name not in subfamily_names:
+            subfamily_name = subfamily_name_default
         full_name = concat_names(family_name, style_name)
-        postscript_family_name = family_name.replace(" ", "")
-        postscript_style_name = style_name.replace(" ", "")
+
+        # postscript name
+        postscript_family_name = typographic_family_name.replace(" ", "")
+        postscript_style_name = typographic_subfamily_name.replace(" ", "")
         postscript_name = concat_names(postscript_family_name, postscript_style_name)
         postscript_name = re.sub(r"[^a-zA-Z0-9\-]", "-", postscript_name)
         postscript_name = re.sub(r"[\-]+", "-", postscript_name).strip("-")
@@ -894,9 +907,10 @@ class Font(object):
                 f" ({postscript_name_length} characters)."
             )
 
+        # update name records
         names = {
             self.NAME_FAMILY_NAME: family_name,
-            self.NAME_SUBFAMILY_NAME: style_name,  # .lower(),
+            self.NAME_SUBFAMILY_NAME: subfamily_name,
             self.NAME_FULL_NAME: full_name,
             self.NAME_POSTSCRIPT_NAME: postscript_name,
             self.NAME_TYPOGRAPHIC_FAMILY_NAME: typographic_family_name,
